@@ -1,4 +1,7 @@
 """Basic set of tests to ensure entire code base is importable"""
+
+# ruff: noqa: PLC0415
+
 import pytest
 
 
@@ -6,8 +9,6 @@ def test_importable():
     """Simple smoketest to ensure all isort modules are importable"""
 
     import isort
-    import isort._future
-    import isort._future._dataclasses
     import isort._version
     import isort.api
     import isort.comments
@@ -21,7 +22,6 @@ def test_importable():
     import isort.parse
     import isort.place
     import isort.profiles
-    import isort.pylama_isort
     import isort.sections
     import isort.settings
     import isort.setuptools_commands
@@ -37,6 +37,9 @@ def test_importable():
     import isort.stdlibs.py39
     import isort.stdlibs.py310
     import isort.stdlibs.py311
+    import isort.stdlibs.py312
+    import isort.stdlibs.py313
+    import isort.stdlibs.py314
     import isort.utils
     import isort.wrap
     import isort.wrap_modes
